==> huaweicloudsdkiotda-3.1.63-py2.py3-none-any.whl: huaweicloudsdkiotda/v5/model/list_device_tunnels_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListDeviceTunnelsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'tunnels': 'list[TunnelInfo]'
    }

    attribute_map = {
        'tunnels': 'tunnels'
    }

    def __init__(self, tunnels=None):
        """ListDeviceTunnelsResponse

        The model defined in huaweicloud sdk

        :param tunnels: 隧道信息列表。
        :type tunnels: list[:class:`huaweicloudsdkiotda.v5.TunnelInfo`]
        """
        
        super(ListDeviceTunnelsResponse, self).__init__()

        self._tunnels = None
        self.discriminator = None

        if tunnels is not None:
            self.tunnels = tunnels

    @property
    def tunnels(self):
        """Gets the tunnels of this ListDeviceTunnelsResponse.

        隧道信息列表。

        :return: The tunnels of this ListDeviceTunnelsResponse.
        :rtype: list[:class:`huaweicloudsdkiotda.v5.TunnelInfo`]
        """
        return self._tunnels

    @tunnels.setter
    def tunnels(self, tunnels):
        """Sets the tunnels of this ListDeviceTunnelsResponse.

        隧道信息列表。

        :param tunnels: The tunnels of this ListDeviceTunnelsResponse.
        :type tunnels: list[:class:`huaweicloudsdkiotda.v5.TunnelInfo`]
        """
        self._tunnels = tunnels

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListDeviceTunnelsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiotda-3.1.153-py2.py3-none-any.whl: huaweicloudsdkiotda/v5/model/list_device_tunnels_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListDeviceTunnelsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'tunnels': 'list[TunnelInfo]'
    }

    attribute_map = {
        'tunnels': 'tunnels'
    }

    def __init__(self, tunnels=None):
        r"""ListDeviceTunnelsResponse

        The model defined in huaweicloud sdk

        :param tunnels: 隧道信息列表。
        :type tunnels: list[:class:`huaweicloudsdkiotda.v5.TunnelInfo`]
        """
        
        super(ListDeviceTunnelsResponse, self).__init__()

        self._tunnels = None
        self.discriminator = None

        if tunnels is not None:
            self.tunnels = tunnels

    @property
    def tunnels(self):
        r"""Gets the tunnels of this ListDeviceTunnelsResponse.

        隧道信息列表。

        :return: The tunnels of this ListDeviceTunnelsResponse.
        :rtype: list[:class:`huaweicloudsdkiotda.v5.TunnelInfo`]
        """
        return self._tunnels

    @tunnels.setter
    def tunnels(self, tunnels):
        r"""Sets the tunnels of this ListDeviceTunnelsResponse.

        隧道信息列表。

        :param tunnels: The tunnels of this ListDeviceTunnelsResponse.
        :type tunnels: list[:class:`huaweicloudsdkiotda.v5.TunnelInfo`]
        """
        self._tunnels = tunnels

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListDeviceTunnelsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
